@@ -1,9 +1,9 @@
 /* Test of copying of files.
-   Copyright (C) 2008-2022 Free Software Foundation, Inc.
+   Copyright (C) 2008-2025 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -40,7 +40,7 @@ main (int argc, char *argv[])
   if (null_stderr)
     ASSERT (qcopy_file_preserving (file1, file2) == 0);
   else
-    copy_file_preserving (file1, file2);
+    xcopy_file_preserving (file1, file2);
 
-  return 0;
+  return test_exit_status;
 }
